@@ -130,6 +130,85 @@ make.clusterNames = function(n) {
 }
 
 
+#' @noRd
+#' @param clusterNames Names of the clusters
+#' @param clusterOrder Vector indicating the selection and ordering of the clusters, by name or index
+#' @param subset Whether to allow for a subset selection
+#' @details
+#' If no ordering is specific (empty vector), then the original cluster names are returned
+#' @keywords internal
+make.orderedClusterNames = function(clusterNames, clusterOrder = character(), subset = TRUE) {
+  assert_that(
+    is.character(clusterNames),
+    is.character(clusterOrder) || is.numeric(clusterOrder),
+    is.flag(subset),
+    length(clusterNames) > 0,
+    all(nzchar(clusterNames)),
+    anyDuplicated(clusterOrder) == 0,
+    length(clusterOrder) <= length(clusterNames),
+    subset || length(clusterOrder) == length(clusterNames)
+  )
+
+  if (length(clusterOrder) == 0) {
+    return (clusterNames)
+  }
+
+  if (is.numeric(clusterOrder)) {
+    assert_that(
+      all(clusterOrder %in% seq(1, length(clusterNames))),
+      msg = 'clusterOrder argument has invalid indices'
+    )
+    clusterNames[clusterOrder]
+  }
+  else {
+    assert_that(
+      all(clusterOrder %in% clusterNames)
+    )
+    clusterOrder
+  }
+}
+
+
+#' @export
+#' @rdname lcModel-make
+#' @description `make.clusterSizeLabels` generates cluster labels for the given input
+#' @param clusterNames Names of the clusters
+#' @param sizes Sizes of the respective clusters; the number of ids
+#' @examples
+#' make.clusterSizeLabels(c('A', 'B'), c(10, 20))
+make.clusterSizeLabels = function(clusterNames, sizes) {
+  assert_that(
+    is.character(clusterNames),
+    length(clusterNames) > 0,
+    length(clusterNames) == length(sizes),
+    is.numeric(sizes),
+    all(vapply(sizes, is.number, FUN.VALUE = TRUE)),
+    all(sizes >= 0)
+  )
+
+  sprintf('%s (%d)', clusterNames, sizes)
+}
+
+
+#' @export
+#' @rdname lcModel-make
+#' @description `make.clusterPropLabels` generates cluster labels for the given input
+#' @examples
+#' make.clusterPropLabels(c('A', 'B'), c(10, 20))
+make.clusterPropLabels = function(clusterNames, sizes) {
+  make.clusterSizeLabels(clusterNames, sizes) # just to check the inputs
+
+  n = sum(sizes)
+  assert_that(n > 0, msg = 'cannot generate cluster labels: all clusters are empty')
+
+  sprintf(
+    '%s (%g%%)',
+    clusterNames,
+    round(sizes / n * 100)
+  )
+}
+
+
 #' @noRd
 #' @title Generate unique IDs vector from input
 #' @details Used by models to choose the ordering of trajectories in the ids() vector in a standardized manner.
