@@ -26,7 +26,6 @@ NULL
 
 #' @export
 #' @name lcMethod-class
-#' @rdname lcMethod-class
 #' @aliases lcMethod
 #' @title lcMethod class
 #' @description `lcMethod` objects represent the specification of a method for longitudinal clustering.
@@ -287,6 +286,7 @@ as.lcMethod = function(x, ..., envir = parent.frame()) {
 }
 
 
+#' @exportS3Method base::as.character
 as.character.lcMethod = function(x, ..., eval = FALSE, width = 40, prefix = '', envir = NULL) {
   assert_that(
     is.lcMethod(x),
@@ -333,7 +333,7 @@ as.character.lcMethod = function(x, ..., eval = FALSE, width = 40, prefix = '',
 }
 
 
-#' @export
+#' @exportS3Method base::as.list
 #' @title Extract the method arguments as a list
 #' @param x The `lcMethod` object.
 #' @param ... Additional arguments.
@@ -400,7 +400,7 @@ as.list.lcMethod = function(x, ..., args = names(x), eval = TRUE, expand = FALSE
 }
 
 
-#' @export
+#' @exportS3Method base::as.data.frame
 #' @title Convert lcMethod arguments to a list of atomic types
 #' @description Converts the arguments of a `lcMethod` to a named `list` of [atomic] types.
 #' @inheritParams as.list.lcMethod
@@ -486,7 +486,7 @@ as.data.frame.lcMethod = function(x, ..., eval = TRUE, nullValue = NA, envir = N
 
 #. compose ####
 #' @export
-#' @name compose
+#' @rdname compose
 #' @aliases compose,lcMethod-method
 #' @title `lcMethod` estimation step: compose an lcMethod object
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -518,7 +518,7 @@ setMethod('compose', 'lcMethod', function(method, envir = NULL) {
 
 # . fit ####
 #' @export
-#' @name fit
+#' @rdname fit
 #' @aliases fit,lcMethod-method
 #' @title `lcMethod` estimation step: logic for fitting the method to the processed data
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -527,7 +527,6 @@ setMethod('compose', 'lcMethod', function(method, envir = NULL) {
 #' The `fit()` function of the `lcMethod` object estimates the model with the evaluated method specification, processed training data, and prepared environment.
 #' @inheritParams preFit
 #' @param envir The `environment` containing variables generated by [prepareData()] and [preFit()].
-#' @return The fitted object inheriting from `lcModel`.
 #' @section Implementation:
 #' This method should be implemented for all `lcMethod` subclasses.
 #'
@@ -557,7 +556,7 @@ setMethod('fit', 'lcMethod', function(method, data, envir, verbose) {
 })
 
 
-#' @export
+#' @exportS3Method stats::formula
 #' @title Extract formula
 #' @description Extracts the associated `formula` for the given distributional parameter.
 #' @inheritParams as.list.lcMethod
@@ -589,7 +588,7 @@ formula.lcMethod = function(x, what = 'mu', envir = NULL, ...) {
 
 
 
-#' @export
+#' @exportS3Method stats::getCall
 getCall.lcMethod = function(x, ...) {
   assert_that(is.lcMethod(x))
   do.call(call, c(class(x)[1], eapply(x@arguments, enquote)))
@@ -597,14 +596,11 @@ getCall.lcMethod = function(x, ...) {
 
 #. getArgumentDefaults ####
 #' @export
-#' @name getArgumentDefaults
+#' @rdname getArgumentDefaults
 #' @aliases getArgumentDefaults,lcMethod-method
-#' @title Default argument values for lcMethod subclass
 #' @description Returns the default arguments associated with the respective `lcMethod` subclass.
 #' These arguments are automatically included into the `lcMethod` object during initialization.
 #'
-#' @param object The `lcMethod` object.
-#' @return A named `list` of argument values.
 #' @section Implementation:
 #' Although implementing this method is optional, it prevents users from
 #' having to specify all arguments every time they want to create a method specification.
@@ -626,21 +622,25 @@ getCall.lcMethod = function(x, ...) {
 #'
 #' It is recommended to add `callNextMethod()` to the end of the list.
 #' This enables inheriting the default arguments from superclasses.
-#' @seealso [lcMethod] [getArgumentExclusions]
+#' @seealso [lcMethod]
 #' @family lcMethod implementations
 setMethod('getArgumentDefaults', 'lcMethod', function(object) {
   set_names(list(), character(0))
 })
 
+
+#. getCitation ####
+#' @rdname getCitation
+#' @aliases getCitation,lcMethod-method
+setMethod('getCitation', 'lcMethod', function(object, ...) {
+  utils::citation(package = 'base')[0]
+})
+
+
 #. getArgumentExclusions ####
 #' @export
-#' @name getArgumentExclusions
+#' @rdname getArgumentExclusions
 #' @aliases getArgumentExclusions,lcMethod-method
-#' @title Arguments to be excluded for lcMethod subclass
-#' @description Returns the names of arguments that should be excluded during instantiation of the `lcMethod`.
-#'
-#' @param object The `lcMethod` object.
-#' @return A `character` vector of argument names.
 #' @section Implementation:
 #' This function only needs to be implemented if you want to avoid users from specifying
 #' redundant arguments or arguments that are set automatically or conditionally on other arguments.
@@ -664,16 +664,11 @@ setMethod('getArgumentExclusions', 'lcMethod', function(object) {
 
 #. getLabel ####
 #' @export
-#' @name getLabel
 #' @rdname getLabel
 #' @aliases getLabel,lcMethod-method
-#' @title Extract the method label.
 #' @description Extracts the assigned label from the given `lcMethod` or `lcModel` object.
 #' By default, the label is determined from the `"label"` argument of the `lcMethod` object.
 #' The label of an `lcModel` object is set upon estimation by [latrend()] to the label of its associated `lcMethod` object.
-#' @param object The `lcMethod` or `lcModel` object.
-#' @param ... Additional arguments.
-#' @return The extracted label, as `character`.
 #' @seealso [getName] [getShortName]
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time, time = "Time")
@@ -691,15 +686,8 @@ setMethod('getLabel', 'lcMethod', function(object, ...) {
 
 #. getName ####
 #' @export
-#' @name getName
 #' @rdname getName
 #' @aliases getName,lcMethod-method
-#' @title Get the (short) name of the lcMethod or Model
-#' @description Extract the full or shortened name of the given `lcMethod` or `lcModel` object.
-#' The name of the fitted `lcModel` is determined by its associated `lcMethod` name and label, unless specified otherwise.
-#' @param object The `lcMethod` or `lcModel` object.
-#' @param ... Additional arguments.
-#' @return A `character` name.
 #' @section Implementation:
 #' When implementing your own `lcMethod` subclass, override these methods to provide full and abbreviated names.
 #' \preformatted{
@@ -711,50 +699,45 @@ setMethod('getLabel', 'lcMethod', function(object, ...) {
 #' Similar methods can be implemented for your `lcModel` subclass,
 #' however in practice this is not needed as the names are determined by default from the `lcMethod` object that was used to fit the `lcModel` object.
 #'
-#' @seealso [getLabel]
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time)
 #' getName(method) # "lm-kmeans"
 setMethod('getName', 'lcMethod', function(object, ...) 'undefined')
 
+
 #' @export
-#' @name latrend-generics
+#' @rdname getName
 #' @aliases getName,NULL-method
 setMethod('getName', 'NULL', function(object, ...) 'null')
 
+
 #. getShortName ####
 #' @export
-#' @name getShortName
 #' @rdname getName
 #' @aliases getShortName,lcMethod-method
-#' @title Extract the short object name
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time)
 #' getShortName(method) # "LMKM"
 setMethod('getShortName', 'lcMethod', function(object, ...) getName(object, ...))
 
+
 #' @export
-#' @name latrend-generics
+#' @rdname getName
 #' @aliases getShortName,NULL-method
 setMethod('getShortName', 'NULL', function(object, ...) 'nul')
 
 
 #. idVariable ####
 #' @export
-#' @name idVariable
 #' @rdname idVariable
 #' @aliases idVariable,lcMethod-method
-#' @title Extract the trajectory identifier variable
-#' @description Extracts the trajectory identifier variable (i.e., column name) from the given `object`.
-#' @param object The object to extract the variable from.
-#' @param ... Not used.
-#' @return The trajectory identifier name, as `character`.
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time, id = "Traj")
 #' idVariable(method) # "Traj"
 #'
 setMethod('idVariable', 'lcMethod', function(object, ...) object$id)
 
+
 #' @export
 #' @title Check whether the argument of a lcMethod has a defined value.
 #' @description Determines whether the associated argument value is defined. If the argument value is of type `language`, the argument is evaluated to see if it can be resolved within its `environment`.
@@ -789,6 +772,7 @@ isArgDefined = function(object, name, envir = environment(object)) {
 #' @rdname is
 #' @title Check if object is of Class
 #' @param x The object to check the class of.
+#' @return `scalar logical`
 #' @keywords internal
 is.lcMethod = function(x) {
   isS4(x) && inherits(x, 'lcMethod')
@@ -800,7 +784,7 @@ is.lcMethod = function(x) {
 #' @name names,lcMethod-method
 #' @rdname names-lcMethod-method
 #' @aliases length,lcMethod-method
-#' @return The number of arguments, as `integer`.
+#' @return The number of arguments, as `scalar integer`.
 setMethod('length', 'lcMethod', function(x) {
   length(x@arguments)
 })
@@ -828,7 +812,7 @@ setMethod('names', 'lcMethod', function(x) {
 
 
 # . preFit ####
-#' @name preFit
+#' @rdname preFit
 #' @aliases preFit,lcMethod-method
 #' @title `lcMethod` estimation step: method preparation logic
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -854,7 +838,7 @@ setMethod('preFit', 'lcMethod', function(method, data, envir, verbose) {
 
 
 # . prepareData ####
-#' @name prepareData
+#' @rdname prepareData
 #' @aliases prepareData,lcMethod-method
 #' @title `lcMethod` estimation step: logic for preparing the training data
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -894,7 +878,7 @@ setMethod('prepareData', 'lcMethod', function(method, data, verbose) {
 
 
 # . postFit ####
-#' @name postFit
+#' @rdname postFit
 #' @aliases postFit,lcMethod-method
 #' @title `lcMethod` estimation step: logic for post-processing the fitted lcModel
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -933,7 +917,7 @@ setMethod('postFit', 'lcMethod', function(method, data, model, envir, verbose) {
 })
 
 
-#' @export
+#' @exportS3Method base::print
 #' @title Print the arguments of an lcMethod object
 #' @param x The `lcMethod` object.
 #' @param eval Whether to print the evaluated argument values.
@@ -946,8 +930,8 @@ print.lcMethod = function(x, ..., eval = FALSE, width = 40, envir = NULL) {
 }
 
 
+#' @exportS3Method R.utils::evaluate
 #' @importFrom R.utils evaluate
-#' @export
 #' @title Substitute the call arguments for their evaluated values
 #' @description Substitutes the call arguments if they can be evaluated without error.
 #' @inheritParams as.list.lcMethod
@@ -1093,14 +1077,8 @@ update.lcMethod = function(object, ..., .eval = FALSE, .remove = character(), en
 
 #. responseVariable ####
 #' @export
-#' @name responseVariable
 #' @rdname responseVariable
 #' @aliases responseVariable,lcMethod-method
-#' @title Extract the response variable
-#' @description Extracts the response variable from the given `object`.
-#' @param object The object to extract the response variable from.
-#' @param ... Additional arguments.
-#' @return The response variable name as a `character`.
 #' @details If the `lcMethod` object specifies a `formula` argument, then the response is extracted from the response term of the formula.
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time)
@@ -1138,7 +1116,6 @@ setMethod('show', 'lcMethod', function(object) {
 
 # . strip ####
 #' @export
-#' @name strip
 #' @rdname strip
 #' @aliases strip,lcMethod-method
 setMethod('strip', 'lcMethod', function(object, ..., classes = 'formula') {
@@ -1166,7 +1143,6 @@ setMethod('strip', 'lcMethod', function(object, ..., classes = 'formula') {
 
 
 #' @export
-#' @name strip
 #' @rdname strip
 #' @aliases strip,ANY-method
 setMethod('strip', 'ANY', function(object, ..., classes = 'formula') {
@@ -1182,13 +1158,8 @@ setMethod('strip', 'ANY', function(object, ..., classes = 'formula') {
 
 #. timeVariable ####
 #' @export
-#' @name timeVariable
 #' @rdname timeVariable
 #' @aliases timeVariable,lcMethod-method
-#' @title Extract the time variable
-#' @description Extracts the time variable (i.e., column name) from the given `object`.
-#' @param object The object to extract the variable from.
-#' @param ... Additional arguments.
 #' @return The time variable name, as `character`.
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
@@ -1198,7 +1169,7 @@ setMethod('timeVariable', 'lcMethod', function(object, ...) object$time)
 
 #. validate ####
 #' @export
-#' @name validate
+#' @rdname validate
 #' @aliases validate,lcMethod-method
 #' @title `lcMethod` estimation step: method argument validation logic
 #' @description Note: this function should not be called directly, as it is part of the `lcMethod` [estimation procedure][lcMethod-estimation].
@@ -1218,8 +1189,6 @@ setMethod('timeVariable', 'lcMethod', function(object, ...) object$time)
 #' @param method An object inheriting from `lcMethod` with all its arguments having been evaluated and finalized.
 #' @param data A `data.frame` representing the transformed training data.
 #' @param ... Not used.
-#' @return Either `TRUE` if all validation checks passed,
-#' or a `character` containing a description of the failed validation checks.
 #' @inheritSection lcMethod-estimation Estimation procedure
 #' @section Implementation:
 #' An example implementation checking for the existence of specific arguments and type:
