@@ -1,5 +1,4 @@
 #' @include method.R trajectories.R latrend.R
-#' @importFrom stats coef deviance df.residual getCall logLik model.frame model.matrix predict residuals sigma time update
 
 # Model ####
 #' @name lcModel
@@ -171,15 +170,11 @@ setValidity('lcModel', function(object) {
 
 # . clusterTrajectories ####
 #' @export
-#' @name clusterTrajectories
 #' @rdname clusterTrajectories
 #' @aliases clusterTrajectories,lcModel-method
-#' @title Extract the cluster trajectories
-#' @description Extracts a data frame of all cluster trajectories.
 #' @inheritParams predict.lcModel
 #' @inheritParams predictForCluster
-#' @param at An optional vector of the times at which to compute the cluster trajectory predictions.
-#' @return A data.frame of the estimated values at the given times. The first column should be named "Cluster". The second column should be time, with the name matching the `timeVariable(object)`. The third column should be the expected value of the observations, named after the `responseVariable(object)`.
+#' @param ... For `lcModel` objects: Arguments passed to [predict.lcModel].
 #' @examples
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
 #' model <- latrend(method, latrendData)
@@ -279,21 +274,18 @@ clusterSizes = function(object, ...) {
 
 #. clusterProportions ####
 #' @export
-#' @name clusterProportions
+#' @rdname clusterProportions
 #' @aliases clusterProportions,lcModel-method
-#' @title Proportional size of each cluster
-#' @description Obtain the proportional size per cluster, with sizes between 0 and 1.
+#' @param ... For `lcModel` objects: Additional arguments passed to [postprob()].
+#' @section lcModel:
 #' By default, the cluster proportions are determined from the cluster-averaged posterior probabilities of the fitted data (as computed by the [postprob()] function).
-#' @section Implementation:
+#'
 #' Classes extending `lcModel` can override this method to return, for example, the exact estimated mixture proportions based on the model coefficients.
 #' \preformatted{
 #' setMethod("clusterProportions", "lcModelExt", function(object, ...) {
 #'   # return cluster proportion vector
 #' })
 #' }
-#' @param object The `lcModel` to obtain the proportions from.
-#' @param ... Additional arguments passed to [postprob()].
-#' @return A named `numeric vector` of length `nClusters(object)` with the proportional size of each cluster.
 #' @seealso [clusterSizes] [postprob]
 #' @examples
 #' data(latrendData)
@@ -316,7 +308,7 @@ setMethod('clusterProportions', 'lcModel', function(object, ...) {
 })
 
 
-#' @export
+#' @exportS3Method stats::coef
 #' @importFrom stats coef
 #' @title Extract lcModel coefficients
 #' @description Extract the coefficients of the `lcModel` object, if defined.
@@ -351,14 +343,9 @@ coef.lcModel = function(object, ...) {
 
 # . converged ####
 #' @export
-#' @name converged
+#' @rdname converged
 #' @aliases converged,lcModel-method
-#' @title Check model convergence
-#' @description Check convergence of the fitted `lcModel` object.
-#' The default implementation returns `NA`.
-#' @param object The `lcModel` to check for convergence.
-#' @param ... Additional arguments.
-#' @return Either `logical` indicating convergence, or a `numeric` status code.
+#' @return The default `lcModel` implementation returns `NA`.
 #' @section Implementation:
 #' Classes extending `lcModel` can override this method to return a convergence status or code.
 #' \preformatted{
@@ -377,7 +364,7 @@ setMethod('converged', 'lcModel', function(object, ...) {
 })
 
 
-#' @export
+#' @exportS3Method stats::deviance
 #' @importFrom stats deviance
 #' @title lcModel deviance
 #' @description Get the deviance of the fitted `lcModel` object.
@@ -399,7 +386,7 @@ deviance.lcModel = function(object, ...) {
 }
 
 
-#' @export
+#' @exportS3Method stats::df.residual
 #' @importFrom stats df.residual
 #' @title Extract the residual degrees of freedom from a lcModel
 #' @param object The `lcModel` object.
@@ -474,7 +461,7 @@ setMethod('externalMetric', c('lcModel', 'lcModel'), function(object, object2, n
 })
 
 
-#' @export
+#' @exportS3Method stats::fitted
 #' @importFrom stats fitted
 #' @title Extract lcModel fitted values
 #' @description Returns the cluster-specific fitted values for the given `lcModel` object.
@@ -514,19 +501,16 @@ fitted.lcModel = function(object, ..., clusters = trajectoryAssignments(object))
 
 # . fittedTrajectories ####
 #' @export
-#' @name fittedTrajectories
 #' @rdname fittedTrajectories
 #' @aliases fittedTrajectories,lcModel-method
-#' @title Extract the fitted trajectories for all strata
 #' @param object The model.
 #' @param at The time points at which to compute the id-specific trajectories.
-#' The default implementation merely filters the output of `fitted()`,
-#' so fitted values can only be outputted for times at which the model was trained.
+#' The default implementation merely filters the output, i.e., fitted values can only be outputted for times at which the model was trained.
 #' @param what The distributional parameter to compute the response for.
 #' @param clusters The cluster assignments for the strata to base the trajectories on.
-#' @param ... Additional arguments.
-#' @return A `data.frame` representing the fitted response per trajectory per moment in time for the respective cluster.
-#' @details The default implementation uses the output of `fitted()` of the respective model.
+#' @param ... For `lcModel`: Additional arguments passed to [fitted.lcModel].
+#' @return For `lcModel`: A `data.frame` with columns id, time, response, and "Cluster".
+#' @details The default `lcModel` implementation uses the output of `fitted()` of the respective model.
 #' @examples
 #' data(latrendData)
 #' # Note: not a great example because the fitted trajectories
@@ -537,7 +521,13 @@ fitted.lcModel = function(object, ..., clusters = trajectoryAssignments(object))
 #'
 #' fittedTrajectories(model, at = time(model)[c(1, 2)])
 #' @family lcModel functions
-setMethod('fittedTrajectories', 'lcModel', function(object, at, what, clusters, ...) {
+setMethod('fittedTrajectories', 'lcModel', function(
+    object,
+    at = time(object),
+    what = 'mu',
+    clusters = trajectoryAssignments(object),
+    ...
+  ) {
   assert_that(
     is.null(clusters) || length(clusters) == nIds(object),
     is.numeric(at),
@@ -579,7 +569,7 @@ setMethod('fittedTrajectories', 'lcModel', function(object, at, what, clusters,
 })
 
 
-#' @export
+#' @exportS3Method stats::formula
 #' @importFrom stats formula
 #' @title Extract the formula of a lcModel
 #' @description Get the formula associated with the fitted `lcModel` object.
@@ -613,7 +603,7 @@ formula.lcModel = function(x, what = 'mu', ...) {
 }
 
 
-#' @export
+#' @exportS3Method stats::getCall
 #' @importFrom stats getCall
 #' @title Get the model call
 #' @description Extract the `call` that was used to fit the given `lcModel` object.
@@ -645,15 +635,18 @@ setMethod('getLabel', 'lcModel', function(object, ...) {
   }
 })
 
+
+# . getCitation ####
+#' @export
+#' @rdname getCitation
+#' @aliases getCitation,lcModel-method
+setMethod('getCitation', 'lcModel', function(object, ...) getCitation(getLcMethod(object)))
+
+
 # . getLcMethod ####
 #' @export
-#' @name getLcMethod
 #' @rdname getLcMethod
 #' @aliases getLcMethod,lcModel-method
-#' @title Get the method specification of a lcModel
-#' @description Get the `lcMethod` specification object that was used for fitting the given `lcModel` object.
-#' @param object The `lcModel` object.
-#' @return An `lcMethod` object.
 #' @examples
 #' method <- lcMethodRandom("Y", id = "Id", time = "Time")
 #' model <- latrend(method, latrendData)
@@ -667,6 +660,8 @@ setMethod('getLcMethod', 'lcModel', function(object) object@method)
 #' @export
 #' @rdname getName
 #' @aliases getName,lcModel-method
+#' @details
+#' For `lcModel`: The name is determined by its associated `lcMethod` name and label, unless specified otherwise.
 setMethod('getName', 'lcModel', function(object) {
   basename = getLcMethod(object) %>% getName()
   lbl = getLabel(object)
@@ -677,13 +672,12 @@ setMethod('getName', 'lcModel', function(object) {
   }
 })
 
+
 # . getShortName ####
 #' @export
 #' @rdname getName
 #' @aliases getShortName,lcModel-method
-setMethod('getShortName',  'lcModel',
-  function(object) getShortName(getLcMethod(object))
-)
+setMethod('getShortName',  'lcModel', function(object) getShortName(getLcMethod(object)))
 
 
 # . ids ####
@@ -711,14 +705,12 @@ ids = function(object) {
 
 #. idVariable ####
 #' @export
-#' @name idVariable
 #' @rdname idVariable
 #' @aliases idVariable,lcModel-method
 #' @examples
 #' method <- lcMethodRandom("Y", id = "Id", time = "Time")
 #' model <- latrend(method, latrendData)
 #' idVariable(model) # "Id"
-#' @family lcModel variables
 setMethod('idVariable', 'lcModel', function(object) object@id)
 
 
@@ -731,7 +723,6 @@ is.lcModel = function(x) {
 
 #. metric ####
 #' @export
-#' @name metric
 #' @rdname metric
 #' @aliases metric,lcModel-method
 #' @examples
@@ -785,7 +776,7 @@ setMethod('metric', 'lcModel', function(object, name, ...) {
 })
 
 
-#' @export
+#' @exportS3Method stats::model.frame
 #' @importFrom stats model.frame
 #' @title Extract model training data
 #' @description See [stats::model.frame()] for more details.
@@ -899,32 +890,21 @@ nIds = function(object) {
 
 # . nClusters ####
 #' @export
-#' @name nClusters
+#' @rdname nClusters
 #' @aliases nClusters,lcModel-method
-#' @title Number of clusters
-#' @description Get the number of clusters estimated by the given `lcModel` object.
-#' @param object The `lcModel` object.
-#' @param ... Not used.
-#' @return An `integer` with the number of clusters identified by the `lcModel`.
-#' @seealso [nIds] [nobs]
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodRandom("Y", id = "Id", time = "Time", nClusters = 3)
 #' model <- latrend(method, latrendData)
 #' nClusters(model) # 3
+#' @seealso [nIds] [nobs]
 #' @family lcModel functions
 setMethod('nClusters', 'lcModel', function(object, ...) {
-  nClus = length(object@clusterNames)
-  assert_that(
-    is.count(nClus),
-    nClus > 0
-  )
-  nClus
+  length(object@clusterNames)
 })
 
 
-#' @export
-#' @importFrom stats nobs
+#' @exportS3Method stats::nobs
 #' @title Number of observations used for the lcModel fit
 #' @description Extracts the number of observations that contributed information towards fitting the cluster trajectories of the respective `lcModel` object.
 #' Therefore, only non-missing response observations count towards the number of observations.
@@ -951,9 +931,8 @@ nobs.lcModel = function(object, ...) {
 }
 
 
-#' @export
+#' @exportS3Method stats::predict
 #' @rdname predict.lcModel
-#' @importFrom stats predict
 #' @title lcModel predictions
 #' @description Predicts the expected trajectory observations at the given time for each cluster.
 #' @section Implementation:
@@ -1118,20 +1097,14 @@ predict.lcModel = function(object, newdata = NULL, what = 'mu', ..., useCluster
 
 # . predictForCluster ####
 #' @export
-#' @name predictForCluster
 #' @rdname predictForCluster
 #' @aliases predictForCluster,lcModel-method
-#' @title lcModel prediction conditional on a cluster
-#' @description Predicts the expected trajectory observations at the given time under the assumption that the trajectory belongs to the specified cluster.
-#'
-#' The same result can be obtained by calling [`predict()`][predict.lcModel()] with the `newdata` `data.frame` having a `"Cluster"` assignment column.
+#' @description
+#' For `lcModel` objects, the same result can be obtained by calling [`predict()`][predict.lcModel()] with the `newdata` `data.frame` having a `"Cluster"` assignment column.
 #' The main purpose of this function is to make it easier to implement the prediction computations for custom `lcModel` classes.
-#'
-#' @details The default `predictForCluster()` method makes use of [predict.lcModel()], and vice versa. For this to work, any extending `lcModel` classes, e.g., `lcModelExample`, should implement either `predictForCluster(lcModelExample)` or `predict.lcModelExample()`. When implementing new models, it is advisable to implement `predictForCluster` as the cluster-specific computation generally results in shorter and simpler code.
+#' @details The default `predictForCluster(lcModel)` method makes use of [predict.lcModel()], and vice versa. For this to work, any extending `lcModel` classes, e.g., `lcModelExample`, should implement either `predictForCluster(lcModelExample)` or `predict.lcModelExample()`. When implementing new models, it is advisable to implement `predictForCluster` as the cluster-specific computation generally results in shorter and simpler code.
 #' @inheritParams predict.lcModel
-#' @param cluster The cluster name (as `character`) to predict for.
-#' @param ... Additional arguments.
-#' @return A `vector` with the predictions per `newdata` observation, or a `data.frame` with the predictions and newdata alongside.
+#' @inheritDotParams predict.lcModel
 #' @section Implementation:
 #' Classes extending `lcModel` should override this method, unless [predict.lcModel()] is preferred.
 #' \preformatted{
@@ -1161,11 +1134,18 @@ setMethod('predictForCluster', 'lcModel',
   # check whether predict.lcModelType exists
   cls = class(object)
   classes = extends(class(object)) %>% setdiff('lcModel')
-  methodsAvailable = vapply(classes, function(x) !is.null(getS3method('predict', x, optional = TRUE)), FUN.VALUE = FALSE)
+  methodsAvailable = vapply(
+    classes,
+    function(x) !is.null(getS3method('predict', x, optional = TRUE)),
+    FUN.VALUE = FALSE
+  )
 
   assert_that(
     any(methodsAvailable),
-    msg = sprintf('Cannot compute cluster-specific predictions for model of class %1$s because neither predict.%1$s nor predictForCluster(%1$s) are implemented for this model', cls)
+    msg = sprintf(
+      'Cannot compute cluster-specific predictions for model of class %1$s because neither predict.%1$s nor predictForCluster(%1$s) are implemented for this model',
+      cls
+    )
   )
 
   newdata = cbind(newdata, Cluster = cluster)
@@ -1177,17 +1157,10 @@ setMethod('predictForCluster', 'lcModel',
 
 # . predictPostprob ####
 #' @export
-#' @name predictPostprob
 #' @rdname predictPostprob
 #' @aliases predictPostprob,lcModel-method
-#' @title lcModel posterior probability prediction
-#' @description Returns the observation-specific posterior probabilities for the given data.
-#' The default implementation returns a uniform probability matrix.
-#' @param object The `lcModel` to predict the posterior probabilities with.
-#' @param newdata Optional data frame for which to compute the posterior probability. If omitted, the model training data is used.
-#' @param ... Additional arguments.
-#' @return A N-by-K `matrix` indicating the posterior probability per trajectory per measurement on each row, for each cluster (the columns).
-#' Here, `N = nrow(newdata)` and `K = nClusters(object)`.
+#' @description For `lcModel`: The default implementation returns a uniform probability matrix.
+#' @inheritDotParams postprob
 #' @section Implementation:
 #' Classes extending `lcModel` should override this method to enable posterior probability predictions for new data.
 #' \preformatted{
@@ -1195,6 +1168,7 @@ setMethod('predictForCluster', 'lcModel',
 #'   # return observation-specific posterior probability matrix
 #' })
 #' }
+#' @seealso [postprob]
 #' @family lcModel functions
 setMethod('predictPostprob', 'lcModel', function(object, newdata = NULL, ...) {
   if (is.null(newdata)) {
@@ -1217,16 +1191,12 @@ setMethod('predictPostprob', 'lcModel', function(object, newdata = NULL, ...) {
 
 #. predictAssignments ####
 #' @export
-#' @name predictAssignments
 #' @rdname predictAssignments
 #' @aliases predictAssignments,lcModel-method
-#' @title Predict the cluster assignments for new trajectories
-#' @description Computes the posterior probability based on the provided (observed) data.
 #' @inheritParams predict.lcModel
 #' @param strategy A function returning the cluster index based on the given `vector` of membership probabilities.
 #' By default (`strategy = which.max`), trajectories are assigned to the most likely cluster.
 #' @details The default implementation uses [predictPostprob] to determine the cluster membership.
-#' @return A `factor` of length `nrow(newdata)` that indicates the assigned cluster per trajectory per observation.
 #' @seealso [predictPostprob] [predict.lcModel]
 #' @family lcModel functions
 #' @examples
@@ -1293,14 +1263,12 @@ setMethod('plot', c('lcModel', 'ANY'), function(x, y, ...) {
 
 #. plotFittedTrajectories ####
 #' @export
-#' @name plotFittedTrajectories
 #' @rdname plotFittedTrajectories
 #' @aliases plotFittedTrajectories,lcModel-method
-#' @title Plot fitted trajectories of a lcModel
-#' @param object The `lcModel` object.
-#' @param ... Arguments passed to [fittedTrajectories()].
-#' @inheritDotParams trajectories
-#' @seealso [fittedTrajectories] [plotClusterTrajectories] [plotTrajectories] [plot]
+#' @param ... Arguments passed to [fittedTrajectories()] and [plotTrajectories].
+#' @inheritDotParams plotTrajectories
+#' @return A `ggplot` object.
+#' @seealso [plotClusterTrajectories] [plotTrajectories] [plot]
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
@@ -1324,18 +1292,19 @@ setMethod('plotFittedTrajectories', 'lcModel', function(object, ...) {
 })
 
 #. plotClusterTrajectories ####
-# NOTE: Cannot include @inheritDotParams clusterTrajectories-method because the name is not supported by Roxygen
 #' @export
-#' @name plotClusterTrajectories
 #' @rdname plotClusterTrajectories
 #' @aliases plotClusterTrajectories,lcModel-method
-#' @title Plot the cluster trajectories of a lcModel
-#' @inheritParams clusterTrajectories
-#' @param clusterLabels Cluster display names. By default it's the cluster name with its proportion enclosed in parentheses.
+#' @param clusterLabeler A `function(clusterNames, clusterSizes)` that generates plot labels for the clusters.
+#' By default the cluster name with the proportional size is shown, see [make.clusterPropLabels].
+#' @param clusterOrder Specify which clusters to plot and the order.
+#' Can be the cluster names or index.
+#' By default, all clusters are shown.
 #' @param trajAssignments The cluster assignments for the fitted trajectories. Only used when `trajectories = TRUE` and `facet = TRUE`. See [trajectoryAssignments].
+#' @inheritDotParams clusterTrajectories
 #' @param ... Arguments passed to [clusterTrajectories()], or [ggplot2::geom_line()] for plotting the cluster trajectory lines.
 #' @return A `ggplot` object.
-#' @seealso [clusterTrajectories] [plotFittedTrajectories] [plotTrajectories] [plot]
+#' @seealso [plotTrajectories] [plot]
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
@@ -1344,6 +1313,18 @@ setMethod('plotFittedTrajectories', 'lcModel', function(object, ...) {
 #' if (require("ggplot2")) {
 #'   plotClusterTrajectories(model)
 #'
+#'   # show cluster sizes in labels
+#'   plotClusterTrajectories(model, clusterLabeler = make.clusterSizeLabels)
+#'
+#'   # change cluster order
+#'   plotClusterTrajectories(model, clusterOrder = c('B', 'C', 'A'))
+#'
+#'   # sort clusters by decreasing size
+#'   plotClusterTrajectories(model, clusterOrder = order(-clusterSizes(model)))
+#'
+#'   # show only specific clusters
+#'   plotClusterTrajectories(model, clusterOrder = c('B', 'C'))
+#'
 #'   # show assigned trajectories
 #'   plotClusterTrajectories(model, trajectories = TRUE)
 #'
@@ -1361,26 +1342,21 @@ setMethod('plotFittedTrajectories', 'lcModel', function(object, ...) {
 #' }
 #' @family lcModel functions
 setMethod('plotClusterTrajectories', 'lcModel',
-  function(object,
+  function(
+    object,
     what = 'mu',
     at = time(object),
-    clusterLabels = NULL,
+    clusterOrder = character(),
+    clusterLabeler = make.clusterPropLabels,
     trajectories = FALSE,
     facet = !isFALSE(as.logical(trajectories[1])),
     trajAssignments = trajectoryAssignments(object),
     ...
-  ) {
-  if (is.null(clusterLabels)) {
-    clusterLabels = sprintf(
-      '%s (%g%%)',
-      clusterNames(object),
-      round(clusterProportions(object) * 100)
-    )
-  }
+) {
+  clusterLabels = clusterLabeler(clusterNames(object), clusterSizes(object))
   assert_that(length(clusterLabels) == nClusters(object))
 
   clusdata = clusterTrajectories(object, at = at, what = what, ...) %>% as.data.table()
-  clusdata[, Cluster := factor(Cluster, levels = levels(Cluster), labels = clusterLabels)]
 
   rawdata = model.data(object) %>% as.data.table()
   if (nrow(rawdata) > 0 && !is.null(trajAssignments)) {
@@ -1394,6 +1370,8 @@ setMethod('plotClusterTrajectories', 'lcModel',
 
   .plotClusterTrajs(
     clusdata,
+    clusterOrder = clusterOrder,
+    clusterLabels = clusterLabels,
     response = responseVariable(object, what = what),
     time = timeVariable(object),
     id = idVariable(object),
@@ -1409,7 +1387,7 @@ setMethod('plotClusterTrajectories', 'lcModel',
 #' @export
 #' @rdname plotTrajectories
 #' @aliases plotTrajectories,lcModel-method
-#' @param ... Additional arguments passed to [trajectories()].
+#' @inheritDotParams trajectories
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
@@ -1418,6 +1396,7 @@ setMethod('plotClusterTrajectories', 'lcModel',
 #' if (require("ggplot2")) {
 #'   plotTrajectories(model)
 #' }
+#' @seealso [trajectories]
 setMethod('plotTrajectories', 'lcModel', function(object, ...) {
   data = trajectories(object, ...)
   plotTrajectories(
@@ -1432,15 +1411,9 @@ setMethod('plotTrajectories', 'lcModel', function(object, ...) {
 
 #. postprob ####
 #' @export
-#' @name postprob
 #' @rdname postprob
 #' @aliases postprob,lcModel-method
-#' @title Posterior probability per fitted trajectory
-#' @description Get the posterior probability matrix with element \eqn{(i,j)} indicating the probability of trajectory \eqn{i} belonging to cluster \eqn{j}.
 #' @details This method should be extended by `lcModel` implementations. The default implementation returns uniform probabilities for all observations.
-#' @param object The `lcModel`.
-#' @param ... Additional arguments.
-#' @return A I-by-K `matrix` with `I = nIds(object)` and `K = nClusters(object)`.
 #' @section Implementation:
 #' Classes extending `lcModel` should override this method.
 #' \preformatted{
@@ -1495,16 +1468,13 @@ setMethod('postprob', 'lcModel', function(object, ...) {
 })
 
 
-# . QQ plot ####
 #' @export
 #' @name qqPlot
-#' @rdname qqPlot
-#' @aliases qqPlot,lcModel-method
 #' @title Quantile-quantile plot
 #' @description Plot the quantile-quantile (Q-Q) plot for the fitted `lcModel` object. This function is based on the \pkg{qqplotr} package.
-#' @param object The `lcModel` object.
+#' @param model `lcModel`
 #' @param byCluster Whether to plot the Q-Q line per cluster
-#' @param ... Additional arguments passed to [qqplotr::geom_qq_band()], [qqplotr::stat_qq_line()], and [qqplotr::stat_qq_point()].
+#' @param ... Additional arguments passed to [residuals.lcModel], [qqplotr::geom_qq_band()], [qqplotr::stat_qq_line()], and [qqplotr::stat_qq_point()].
 #' @return A `ggplot` object.
 #' @seealso [residuals.lcModel] [metric] [plotClusterTrajectories]
 #' @examples
@@ -1516,22 +1486,23 @@ setMethod('postprob', 'lcModel', function(object, ...) {
 #'   qqPlot(model)
 #' }
 #' @family lcModel functions
-setMethod('qqPlot', 'lcModel', function(object, byCluster = FALSE, ...) {
+qqPlot = function(model, byCluster = FALSE, ...) {
   .loadOptionalPackage('ggplot2')
+  .loadOptionalPackage('qqplotr')
+
   assert_that(
-    is.lcModel(object),
+    is.lcModel(model),
     is.flag(byCluster)
   )
 
-  res = residuals(object, ...)
-  mdata = model.data(object)
+  res = residuals(model, ...)
+  mdata = model.data(model)
   assert_that(!is.null(mdata), msg = 'no model data available')
 
-  idIndexColumn = factor(mdata[[idVariable(object)]], levels = ids(object)) %>%
+  idIndexColumn = factor(mdata[[idVariable(model)]], levels = ids(model)) %>%
     as.integer()
-  rowClusters = trajectoryAssignments(object)[idIndexColumn]
+  rowClusters = trajectoryAssignments(model)[idIndexColumn]
 
-  requireNamespace('qqplotr')
   p = ggplot2::ggplot(
       data = data.frame(Cluster = rowClusters, res = res),
       mapping = ggplot2::aes(sample = res)
@@ -1550,11 +1521,10 @@ setMethod('qqPlot', 'lcModel', function(object, byCluster = FALSE, ...) {
   }
 
   p
-})
+}
 
 
-#' @export
-#' @importFrom stats residuals
+#' @exportS3Method stats::residuals
 #' @title Extract lcModel residuals
 #' @description Extract the residuals for a fitted `lcModel` object.
 #' By default, residuals are computed under the most likely cluster assignment for each trajectory.
@@ -1582,33 +1552,24 @@ residuals.lcModel = function(object, ..., clusters = trajectoryAssignments(objec
   }
 }
 
+
 #. responseVariable ####
 #' @export
-#' @name responseVariable
 #' @rdname responseVariable
 #' @aliases responseVariable,lcModel-method
-#' @title Get the response variable
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodRandom("Y", id = "Id", time = "Time")
 #' model <- latrend(method, latrendData)
 #' responseVariable(model) # "Y"
-#' @family lcModel variables
 setMethod('responseVariable', 'lcModel', function(object, ...) object@response)
 
+
 # . estimationTime ####
 #' @export
-#' @name estimationTime
 #' @rdname estimationTime
 #' @aliases estimationTime,lcModel-method
-#' @title Get the model estimation time
-#' @description Get the estimation time of the model, determined by the time taken for the associated [fit()] function to finish.
-#' @param object The `lcModel` object.
-#' @param unit The time unit in which the estimation time should be outputted.
-#' By default, estimation time is in seconds.
-#' For accepted units, see [base::difftime].
-#' @param ... Additional arguments.
-#' @return A `numeric` representing the model estimation time, in the specified unit.
+#' @description For `lcModel`: Get the estimation time of the model, determined by the time taken for the associated [fit()] function to finish.
 #' @examples
 #' data(latrendData)
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time")
@@ -1619,20 +1580,18 @@ setMethod('responseVariable', 'lcModel', function(object, ...) object@response)
 #' estimationTime(model, unit = 'days')
 #' @family lcModel functions
 setMethod('estimationTime', 'lcModel', function(object, unit, ...) {
-  assert_that(is.lcModel(object))
-  dtime = as.difftime(object@estimationTime, units = 'secs')
-  as.numeric(dtime, units = unit)
+  as.difftime(object@estimationTime, units = 'secs')
 })
 
 
 # . show ####
 setMethod('show', 'lcModel', function(object) {
   show(summary(object))
+  .suggestCiteMethod(object)
 })
 
 
-#' @export
-#' @importFrom stats sigma
+#' @exportS3Method stats::sigma
 #' @title Extract residual standard deviation from a lcModel
 #' @description Extracts or estimates the residual standard deviation. If [sigma()] is not defined for a model, it is estimated from the residual error vector.
 #' @param object The `lcModel` object.
@@ -1654,15 +1613,9 @@ sigma.lcModel = function(object, ...) {
 
 #. strip ####
 #' @export
-#' @name strip
 #' @rdname strip
 #' @aliases strip,lcModel-method
-#' @title Reduce the lcModel memory footprint for serialization
-#' @description Strip a lcModel of non-essential variables and environments in order to reduce the model size for serialization.
-#' @param object The `lcModel` object.
 #' @param classes The object classes for which to remove their assigned environment. By default, only environments from `formula` are removed.
-#' @param ... Additional arguments.
-#' @return An `lcModel` object of the same type as the `object` argument.
 #' @section Implementation:
 #' Classes extending `lcModel` can override this method to remove additional non-essentials.
 #' \preformatted{
@@ -1691,7 +1644,6 @@ setMethod('strip', 'lcModel', function(object, ..., classes = 'formula') {
 
 #. timeVariable ####
 #' @export
-#' @name timeVariable
 #' @rdname timeVariable
 #' @aliases timeVariable,lcModel-method
 #' @examples
@@ -1699,12 +1651,10 @@ setMethod('strip', 'lcModel', function(object, ..., classes = 'formula') {
 #' method <- lcMethodRandom("Y", id = "Id", time = "Time")
 #' model <- latrend(method, latrendData)
 #' timeVariable(model) # "Time"
-#' @family lcModel variables
 setMethod('timeVariable', 'lcModel', function(object) object@time)
 
 
-#' @export
-#' @importFrom stats time
+#' @exportS3Method stats::time
 #' @title Sampling times of a lcModel
 #' @description Extract the sampling times on which the `lcModel` was fitted.
 #' @param x The `lcModel` object.
@@ -1755,18 +1705,16 @@ setMethod('trajectories', 'lcModel', function(object, ...) {
 
 #. trajectoryAssignments ####
 #' @export
-#' @name trajectoryAssignments
+#' @rdname trajectoryAssignments
 #' @aliases trajectoryAssignments,lcModel-method
-#' @title Get the cluster membership of each trajectory
-#' @description Classify the fitted trajectories based on the posterior probabilities computed by [postprob()], according to a given classification strategy.
+#' @description
+#' For `lcModel`: Classify the fitted trajectories based on the posterior probabilities computed by [postprob()], according to a given classification strategy.
 #'
 #' By default, trajectories are assigned based on the highest posterior probability using [which.max()].
 #' In cases where identical probabilities are expected between clusters, it is preferable to use \link[nnet]{which.is.max} instead, as this function breaks ties at random.
 #' Another strategy to consider is the function [which.weight()], which enables weighted sampling of cluster assignments based on the trajectory-specific probabilities.
-#' @param object The object to obtain the cluster assignments from.
 #' @param strategy A function returning the cluster index based on the given vector of membership probabilities. By default, ids are assigned to the cluster with the highest probability.
 #' @param ... Any additional arguments passed to the strategy function.
-#' @return A `factor` indicating the cluster membership for each trajectory.
 #' @seealso [postprob] [clusterSizes] [predictAssignments]
 #' @examples
 #' data(latrendData)
@@ -1803,8 +1751,7 @@ setMethod('trajectoryAssignments', 'lcModel', function(object, strategy = which.
 })
 
 
-#' @export
-#' @importFrom stats update
+#' @exportS3Method stats::update
 #' @title Update a lcModel
 #' @description Fit a new model with modified arguments from the current model.
 #' @param object The `lcModel` object.
